package com.example;

import java.io.File;
import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.openqa.selenium.WebDriver;
import org.openqa.selenium.firefox.FirefoxDriver;
import org.openqa.selenium.firefox.FirefoxProfile;
import org.openqa.selenium.remote.DesiredCapabilities;
import org.slf4j.LoggerFactory;

public class FirefoxWebdriverService {

    private static final org.slf4j.Logger logger = LoggerFactory
            .getLogger(FirefoxWebdriverService.class);

    private WebDriver driver;
    private static FirefoxWebdriverService fireFoxWebdriverService;

    private FirefoxWebdriverService() {

    }

    public static FirefoxWebdriverService getInstance() {
        if (fireFoxWebdriverService == null) {
            fireFoxWebdriverService = new FirefoxWebdriverService();
        }
        return fireFoxWebdriverService;
    }

    public WebDriver getFirefoxWithFirebug3() {

        /*** Change the below value before running the test***/
        String logLocation = "E:\\NetExport";

        FirefoxProfile profile = new FirefoxProfile();

        //Add extensions to the profile
        try {
            URI fireBugURI = getClass().getResource("/firebug-3.0.0-alpha.9.xpi").toURI();
            File firebug = new File(fireBugURI);
            profile.addExtension(firebug);
            logger.info("fireBugURI is " + fireBugURI);
        } catch (URISyntaxException | IOException ex) {
            Logger.getLogger(FirefoxWebdriverService.class.getName()).log(Level.SEVERE, null, ex);
        }

        //Set default Firefox preferences
        profile.setAssumeUntrustedCertificateIssuer(false); //Accepting untrusted certificates
        profile.setPreference("extensions.checkCompatibility", false);
        profile.setPreference("extensions.checkUpdateSecurity", false);
        profile.setPreference("app.update.enabled", false); //Disable Firefox auto update
        profile.setPreference("browser.startup.homepage", "about:blank");
        profile.setPreference("browser.startup.homepage_override.mstone", "ignore"); //Hide the first run page

        //NetMonitor panel preferences
        profile.setPreference("devtools.theme", "firebug");
        profile.setPreference("devtools.toolbox.selectedTool", "netmonitor"); //The net panel is selected by default
        profile.setPreference("devtools.netmonitor.enabled", true);  //Net panel is enabled by default
        //profile.setPreference("devtools.webconsole.persistlog", true); //Specifies whether NetMonitor is pesisted by default


        //Set default Firebug preferences
        String domain = "extensions.firebug";
        profile.setPreference(domain + "@software.joehewitt.com.allPagesActivation", "on"); //Firebug is activated for all pages by default
        profile.setPreference("extensions.firebug.DBG_NET/EXPORT/AUTOMATION", true);

        //Set default NetExport preferences
        profile.setPreference(domain + "@software.joehewitt.com.netexport.pageLoadedTimeout", 0);
        //profile.setPreference(domain + "@software.joehewitt.com.netexport.timeout", 0);
        profile.setPreference(domain + "@software.joehewitt.com.netexport.alwaysEnableAutoExport", true); //Enable auto export
        profile.setPreference(domain + "@software.joehewitt.com.netexport.showPreview", false); //Do not show a preview for exported data
        profile.setPreference(domain + "@software.joehewitt.com.netexport.defaultLogDir", logLocation); //Store HAR files here
        profile.setPreference(domain + "@software.joehewitt.com.netexport.includeResponseBodies", false);

        //Net export server preferences
        //profile.setPreference(domain + "@software.joehewitt.com.netexport.beaconServerURL", "http://localhost/har-db"); //Exported HAR files will be sent to this URL
        //profile.setPreference(domain + "@software.joehewitt.com.netexport.autoExportToFile", false); //Do not save HARs into files in this scenario
        //profile.setPreference(domain + "@software.joehewitt.com.netexport.autoExportToServer", true); //Send files to the server
        //profile.setPreference(domain + "@software.joehewitt.com.netexport.compress", true); //Compress files using zip
        //profile.setPreference(domain + "@software.joehewitt.com.netexport.sendToConfirmation", false); //Do not open a confirmation dialog when sending a HAR file

        profile.setPreference(domain + "@software.joehewitt.com.netexport.saveFiles", false);
        profile.setPreference(domain + "@software.joehewitt.com.netexport.secretToken", "abcde");



        DesiredCapabilities capabilities = DesiredCapabilities.firefox();
        capabilities.setCapability(FirefoxDriver.PROFILE, profile);
        driver = new FirefoxDriver(capabilities);

        return driver;
    }

    public WebDriver getFirefoxWithFB209NetExport09() {
        FirefoxProfile profile = new FirefoxProfile();

        //Add extensions to the profile
        try {
            URI fireBugURI = getClass().getResource("/firebug-2.0.9-fx.xpi").toURI();
            File firebug = new File(fireBugURI);
            profile.addExtension(firebug);
            logger.info("fireBugURI is " + fireBugURI);

            URI netExportURI = getClass().getResource("/netExport-0.9b7.xpi").toURI();
            File netexport = new File(netExportURI);
            profile.addExtension(netexport);
            logger.info("netExport " + netExportURI);

//            URI fbtraceURI = getClass().getResource("/fbtrace-3.0b1.xpi").toURI();
//            File fbtrace = new File(fbtraceURI);
//            profile.addExtension(fbtrace);
//            logger.info("fbTraceURI is " + fbtraceURI);

        } catch (URISyntaxException | IOException ex) {
            Logger.getLogger(FirefoxWebdriverService.class.getName()).log(Level.SEVERE, null, ex);
        }

        //Set default Firefox preferences
        profile.setAssumeUntrustedCertificateIssuer(false); //Accepting untrusted certificates
        profile.setPreference("extensions.checkCompatibility", false);
        profile.setPreference("extensions.checkUpdateSecurity", false);
        profile.setPreference("app.update.enabled", false); //Disable Firefox auto update

        //Set default Firebug preferences
        String domain = "extensions.firebug.";
        profile.setPreference(domain + "showFirstRunPage", false); //Hide the first run page
        profile.setPreference(domain + "currentVersion", "2.0.9"); //Avoid Firebug start page
        profile.setPreference(domain + "allPagesActivation", "on"); //Firebug is activated for all pages by default
        profile.setPreference(domain + "defaultPanelName", "net"); //The net panel is selected by default
        profile.setPreference(domain + "DBG_NETEXPORT", true);

        //Net panel preferences
        profile.setPreference(domain + "net.enableSites", true);  //Firebug Net panel is enabled by default
        //profile.setPreference(domain + "net.defaultPersist", true); //Specifies whether Net Panel is pesisted by default


        //Set default NetExport preferences
        domain = "extensions.firebug.netexport.";
        profile.setPreference(domain + "pageLoadedTimeout", 0);
        profile.setPreference(domain + "timeout", 0);
        profile.setPreference(domain + "alwaysEnableAutoExport", true); //Enable auto export
        profile.setPreference(domain + "showPreview", false); //Do not show a preview for exported data
        profile.setPreference(domain + "defaultLogDir", "E:\\NetExport"); //Store HAR files here

        //Net export server preferences
        //profile.setPreference(domain + "netexport.Automation", true);
        //profile.setPreference(domain + "beaconServerURL", "http://localhost/har-db"); //Exported HAR files will be sent to this URL
        //profile.setPreference(domain + "autoExportToFile", false); //Do not save HARs into files in this scenario
        //profile.setPreference(domain + "autoExportToServer", true); //Send files to the server
        //profile.setPreference(domain + "sendToConfirmation", false); //Do not open a confirmation dialog when sending a HAR file

        profile.setPreference(domain + "saveFiles", false); //Automatically download all resources. You need DownThemAll installed
        profile.setPreference(domain + "secretToken", "abcde");


        DesiredCapabilities capabilities = DesiredCapabilities.firefox();
        capabilities.setCapability(FirefoxDriver.PROFILE, profile);
        driver = new FirefoxDriver(capabilities);

            return driver;
    }
    
    public WebDriver getFirefoxWithoutExtensions() {
        FirefoxProfile profile = new FirefoxProfile();

        //Set default Firefox preferences
        profile.setAssumeUntrustedCertificateIssuer(false); //Accepting untrusted certificates
        profile.setPreference("extensions.checkCompatibility", false);
        profile.setPreference("extensions.checkUpdateSecurity", false);
        profile.setPreference("app.update.enabled", false); //Disable Firefox auto update
        profile.setPreference("browser.startup.homepage", "about:blank");
        profile.setPreference("browser.startup.homepage_override.mstone", "ignore"); //Hide the first run page

        //NetMonitor panel preferences
        profile.setPreference("devtools.toolbox.selectedTool", "netmonitor"); //The net panel is selected by default
        profile.setPreference("devtools.netmonitor.enabled", true);  //Net panel is enabled by default
        //profile.setPreference("devtools.webconsole.persistlog", true); //Specifies whether NetMonitor is pesisted by default

        DesiredCapabilities capabilities = DesiredCapabilities.firefox();
        capabilities.setCapability(FirefoxDriver.PROFILE, profile);
        driver = new FirefoxDriver(capabilities);

        return driver;
    }
    
}
